

/**
 * The BrowseTestWidget_controller object
 * This is used to wire up the view and model with actions
 */ 
var BrowseTestWidget_controller = {
    /**
     * A dictionary of callback functions that are called whenever an
     * event is fired by this widget.
     */
    callbacks: {},

    init:function() {
        BrowseTestWidget_controller.update();
    },

    /**
     * Update the display
     */
    update:function() { 
        // Is the viewport large enough for the full view?
        var viewport = BrowseTestWidget_controller.getViewport();
        if (viewport.height <= 310  || viewport.width <= 310) {
            $.mobile.changePage($('#tile'));
        } else {
            $.mobile.changePage($('#home'));
        }
    },

   /**
    * Get the current title for this widget.
    */
    getTitle:function() {
        return "Browse Test Widget (Browse Twitter)";
    },

    /**
     * Get the viewport width and height.
     * returns an object with width and height properties.
     */
    getViewport:function() {
	var e = window
	, a = 'inner';
	if ( !( 'innerWidth' in window ) ) {
	    a = 'client';
	    e = document.documentElement || document.body;
	}
	return { width : e[ a + 'Width' ] , height : e[ a + 'Height' ] }
    },

    /**
     * Register a callback function. 
     *
     * type: the name of the type of event to respond to 
     *
     * widget: [optional] the name of the widget where the event must
     * occur for the callback to be executed. This allows callbacks to
     * be register so that they will only respond to events in
     * specific widgets, or to all events.
     */
    register:function(event, callback, widget) {
	if (widget === undefined) {
	    var cbks = BrowseTestWidget_controller.callbacks[event];
	} else {
	    var cbks = BrowseTestWidget_controller.callbacks[widget + "." + event];
	}
	if (cbks === undefined) {
	    cbks = new Array();
	}
	cbks.push(callback);
	BrowseTestWidget_controller.callbacks[event] = cbks;
    },

    /**
     * Execute all the callbacks registered for a given event.
     *
     * The event object is passed directly to the callback function
     * and can contani any number of properties. Two properties that
     * important to the callback functionality are:
     *
     * type: the name of the type of event to respond to 
     *
     * widget: [optional] the name of the widget where the event
     * occured. This allows callbacks to be register so that they will
     * only respond to events in specific widgets, or to all events.
     */
    executeCallbacks:function(event) {
	// Execute all callbacks not restricted to a widget
	var cbks = BrowseTestWidget_controller.callbacks[event.type];
	if (cbks === undefined) return;
	for (var i = 0; i < cbks.length; i++) {
	    cbks[i](event);
	}

	// Execute all callbacks restricted to a widget
	if (event.widget === undefined) return;
	var cbks = BrowseTestWidget_controller.callbacks[event.widget + "." + event.type];
	if (cbks === undefined) return;
	for (var i = 0; i < cbks.length; i++) {
	    cbks[i](event);
	}
    }
};

$('#home').live('pageinit',function(event) {
   BrowseTestWidget_controller.init(); 
});

$('body').bind('orientationchange',function(event){
    BrowseTestWidget_controller.update();
})


/**
 * The BrowseTestWidget_controller object
 * This is used to wire up the view and model with actions
 */ 
var BrowseTestWidget_browse_controller = {
    init:function() {
        //
        // If there is no URL for searching, don't show 
        // the search panel
        //
        var query = "";
        var searchUrl = '"http://search.twitter.com/search.atom?q=" + query + "&rpp=10&include_entities=true&with_twitter_user_id=true&result_type=mixed"'; 
        if(searchUrl === "") $("#searchPanel").hide();
        //
        // If there is a "requiresLogin" attribute, don't
        // trigger search just yet
        //
        if(!BrowseTestWidget_browse_controller.requiresLogin)
        BrowseTestWidget_browse_controller.search()
    },
    
    /**
     * Search the remote service and sort results if possible.
     */
    search:function(query, sort, order) {
	if (sort === undefined) {
	    sort = "updated";
	}
    	if (query === undefined || query == "") {
	    var url = widget.proxify("http://api.twitter.com/1/statuses/public_timeline.xml");
    	} else {
    	    var url = widget.proxify("http://search.twitter.com/search.atom?q=" + query + "&rpp=10&include_entities=true&with_twitter_user_id=true&result_type=mixed");
    	}
    	BrowseTestWidget_browse_controller.populate(url);
    },
	
	
    /**
     * Extract the values from the search form, do the search and display the results.
     */
    submitSearchForm:function() {
	var query = $('#searchString').val();
	var sort = $('#sort').val();
	var order = ($("input[@name='sortOrder']:checked").val());
	BrowseTestWidget_browse_controller.search(query, sort, order);
    },

   /**
    * Get the current title for this widget.
    */
    getTitle:function() {
        return "Browse Test Widget (Browse Twitter)";
    },

   /**
    * Populate the results list with data from a given URL.
    */
    populate:function(sourceUrl) {
        $('#results').remove();
        var html = BrowseTestWidget_browse_controller.transform(sourceUrl, "list");      
        $('#content-primary').html(html).trigger("create");
        $('body').trigger("results_updated");
	    $('.result:first').trigger('expand');
    },
        
    /**
     * Retrieve the details of an item and display them in the detail section.
     */
    displaySummary:function(itemId){
    
        /**
         * Locate the detail element to update
         */
        var detailElement = $(".result[wid='"+itemId+"']").find(".detail");
        
        /**
         * Load the data, showing a loading message while waiting
         */
        detailElement.html("<p>Loading...</p>");
        var sourceUrl = widget.proxify("http://api.twitter.com/1/statuses/show.xml?id=" + itemId + "&include_entities=true");
	    $.mobile.showPageLoadingMsg();
        var html = BrowseTestWidget_browse_controller.transform(sourceUrl, "detail");
        detailElement.html(html);    
        
        /**
         * Add events
         */ 
	    detailElement.click(function() {
	    var event = { widget: "BrowseTestWidget", type: "clickItem", itemId: itemId};	    
	    BrowseTestWidget_controller.executeCallbacks(event);
	});
	$.mobile.hidePageLoadingMsg();
    }			  
}

/**
 * Initialise page layout
 */
$('#home').live('pageinit',function(event) {
   BrowseTestWidget_browse_controller.init(); 
});


/**
 * Display the content of a result item when it is expanded.
 */
$('div.result').live('expand', function(event) {
    var wid = $(this).attr("wid");
    BrowseTestWidget_browse_controller.displaySummary(wid);
    var itemId = wid.substr(wid.indexOf("id=")+3);
    var event = { widget: "BrowseTestWidget", type: "expandItem", itemId: itemId};	    
    BrowseTestWidget_controller.executeCallbacks(event );
});


/**
 * load XML data and transform it into HTML
 * @param src the URL to load
 * @param type the type of data transform requested, either "detail" or "list"
 */
BrowseTestWidget_browse_controller.transform = function(src, type){
 var output = "";
 $.support.cors = true; // force cross-site scripting (as of jQuery 1.5)
 $.ajax({
  url: src,
  dataType: "xml",
  async: false,
  success: function(xml){
    output = BrowseTestWidget_browse_controller.transformXml(xml, type); 
  }, //end success function
    error: function(xhr, textStatus, errorThrown) {
        alert(errorThrown);
    }
 });
 
 return output;
}

/**
 * Transform data into HTML
 */ 
BrowseTestWidget_browse_controller.transformXml = function(xml, type){

    if (type === "detail"){
      template = "<!--  Licensed to the Apache Software Foundation (ASF) under one or more  contributor license agreements.  See the NOTICE file distributed with  this work for additional information regarding copyright ownership.  The ASF licenses this file to You under the Apache License, Version 2.0  (the 'License'); you may not use this file except in compliance with  the License.  You may obtain a copy of the License at      http://www.apache.org/licenses/LICENSE-2.0  Unless required by applicable law or agreed to in writing, software  distributed under the License is distributed on an 'AS IS' BASIS,  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the specific language governing permissions and  limitations under the License.--><p class='clear'><p>${NAME} (${SCREEN_NAME})</p><p>${CREATED_AT}</p></p>";
    } else {
      template = "<!--  Licensed to the Apache Software Foundation (ASF) under one or more  contributor license agreements.  See the NOTICE file distributed with  this work for additional information regarding copyright ownership.  The ASF licenses this file to You under the Apache License, Version 2.0  (the 'License'); you may not use this file except in compliance with  the License.  You may obtain a copy of the License at      http://www.apache.org/licenses/LICENSE-2.0  Unless required by applicable law or agreed to in writing, software  distributed under the License is distributed on an 'AS IS' BASIS,  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the specific language governing permissions and  limitations under the License.--><div class='result' wid='${ID}'><h3><img alt='Avatar for tweet author' src='${PROFILE_IMAGE_URL}'>${TEXT}</h3><div class='detail'></div></div>";
    }
    
    var output = "";
    var items = "";
    
    /**
     * For each element that matches itemName, create a new ItemTemplate and
     * replace placeholders in the template with values from the XML using the ItemElements 
     * and ItemAttrobutes lists
     */
    var elements = BrowseTestWidget_browse_controller.find(xml,"status");
    $(elements).each(
       function(){
         var item = template;
         var elements = "id,name,screen_name,text,profile_image_url,created_at,source".split(",");
         for (var i=0;i<elements.length;i++){
            var element = elements[i]; 
            var pattern = "\\$\{" + element.toUpperCase() +"\}";
            item = item.replace(new RegExp(pattern,'g'), $(this).find(element).first().text());
         }
         var attributes = "id".split(",");
         for (var i=0;i<attributes.length;i++){
            var attribute = attributes[i]; 
            var pattern = '\\$\{'+attribute.toUpperCase()+'\}';
            item = item.replace(new RegExp(pattern,'g'), $(this).attr(attribute));
         }
         items += item;
       }
    );
    
    /**
     * If we are returning a list, wrap the result in the collection template, otherwise
     * just return the item
     */
    if (type === "list"){
       output = "<div id='results' data-role='collapsible-set'>${ITEMS}</div>".replace("${ITEMS}", items);
    } else {
        output = items;
    }
    return output;
}

/**
 * Obtain collection of objects to operate on, either
 * XML elements or JSON objects
 */ 
BrowseTestWidget_browse_controller.find = function(data, name){
  if ("xml"==="xml"){
    return $(data).find(name);
  } else {
    if (!name || name === "") return data;
    return data[name];
  }
}

$('#tile').live('pageinit',function(event) { 
    $('#tile').click(function() {
        window.widget.views.openUrl("http://www.apache.org/widgets/CHANGEME-browse", null, "_blank");
    });
});



var BrowseTestWidget_twoColumn_controller = {
    init:function() {
      BrowseTestWidget_twoColumn_controller.update();
    },

    /**
     * Update the display
     */
    update:function() {
	// expand the search box on screens that are either wide enough (alongside results) or tall enough
	if ($.mobile.media("only screen and (min-width : 801px)")) {
	    $('#content-secondary .ui-collapsible').each(
		function() {
		    $(this).trigger('expand');
		});
	} else if ($.mobile.media("only screen and (min-width : 641px) and (max-width : 1024px)") || $.mobile.media("only screen and (min-width : 1801px)")) {
	    $('#content-secondary .ui-collapsible').each(
		function() {
		    $(this).trigger('expand');
		});
	} else {
	    $('#content-secondary .ui-collapsible').each(
		function() {
		    $(this).trigger('collapse');
		});
	}
    },

}

$('#home').live('pageinit',function(event) {
   BrowseTestWidget_twoColumn_controller.init();
})

