

/**
 * The ItemDetailTestWidget_controller object
 * This is used to wire up the view and model with actions
 */ 
var ItemDetailTestWidget_controller = {
    /**
     * A dictionary of callback functions that are called whenever an
     * event is fired by this widget.
     */
    callbacks: {},

    init:function() {
        ItemDetailTestWidget_controller.update();
    },

    /**
     * Update the display
     */
    update:function() { 
        // Is the viewport large enough for the full view?
        var viewport = ItemDetailTestWidget_controller.getViewport();
        if (viewport.height <= ${widget.tile.max.height}  || viewport.width <= ${widget.tile.max.width}) {
            $.mobile.changePage($('#tile'));
        } else {
            $.mobile.changePage($('#home'));
        }
    },

   /**
    * Get the current title for this widget.
    */
    getTitle:function() {
        return "Item Detail Test Widget (Tweet)";
    },

    /**
     * Get the viewport width and height.
     * returns an object with width and height properties.
     */
    getViewport:function() {
	var e = window
	, a = 'inner';
	if ( !( 'innerWidth' in window ) ) {
	    a = 'client';
	    e = document.documentElement || document.body;
	}
	return { width : e[ a + 'Width' ] , height : e[ a + 'Height' ] }
    },

    /**
     * Register a callback function. 
     *
     * type: the name of the type of event to respond to 
     *
     * widget: [optional] the name of the widget where the event must
     * occur for the callback to be executed. This allows callbacks to
     * be register so that they will only respond to events in
     * specific widgets, or to all events.
     */
    register:function(event, callback, widget) {
	if (widget === undefined) {
	    var cbks = ItemDetailTestWidget_controller.callbacks[event];
	} else {
	    var cbks = ItemDetailTestWidget_controller.callbacks[widget + "." + event];
	}
	if (cbks === undefined) {
	    cbks = new Array();
	}
	cbks.push(callback);
	ItemDetailTestWidget_controller.callbacks[event] = cbks;
    },

    /**
     * Execute all the callbacks registered for a given event.
     *
     * The event object is passed directly to the callback function
     * and can contani any number of properties. Two properties that
     * important to the callback functionality are:
     *
     * type: the name of the type of event to respond to 
     *
     * widget: [optional] the name of the widget where the event
     * occured. This allows callbacks to be register so that they will
     * only respond to events in specific widgets, or to all events.
     */
    executeCallbacks:function(event) {
	// Execute all callbacks not restricted to a widget
	var cbks = ItemDetailTestWidget_controller.callbacks[event.type];
	if (cbks === undefined) return;
	for (var i = 0; i < cbks.length; i++) {
	    cbks[i](event);
	}

	// Execute all callbacks restricted to a widget
	if (event.widget === undefined) return;
	var cbks = ItemDetailTestWidget_controller.callbacks[event.widget + "." + event.type];
	if (cbks === undefined) return;
	for (var i = 0; i < cbks.length; i++) {
	    cbks[i](event);
	}
    }
};

$('#home').live('pageinit',function(event) {
   ItemDetailTestWidget_controller.init(); 
});

$('body').bind('orientationchange',function(event){
    ItemDetailTestWidget_controller.update();
})

/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * The ItemDetailTestWidget_controller object
 * This is used to wire up the view and model with actions
 */ 
var ItemDetailTestWidget_detail_controller = {
    init:function() {
    	var id = ItemDetailTestWidget_detail_controller.get("itemId");
    	if (id === undefined) {
	    id = Widget.preferences.getItem("itemId");
	    if (id === undefined) {
    		id = 129284508087357440
	    }
    	}
	Widget.preferences.setItem("itemId", id);
        ItemDetailTestWidget_detail_controller.populate();
    },
    
   /**
    * Populate the results list with data for a given item.
    * The id of the item is obtained from  Widget.preferences.getItem("itemId");. 
    * The data is transformed using the stylesheet named in the itemDetail.xsl.url property.
    */
    populate:function() {
	var itemId = Widget.preferences.getItem("itemId");
	var url = widget.proxify("http://api.twitter.com/1/statuses/show.xml?id=" + itemId + "&include_entities=false");
        $('#detail').remove();
        var html = ItemDetailTestWidget_detail_controller.transform(url);
        $('#content-primary').html(html).trigger("create");
    },

    /**
     * get a parameter from the URL
     */
    get:function(name){
	if(name=(new RegExp('[?&]'+encodeURIComponent(name)+'=([^&]*)')).exec(location.search))
	    return decodeURIComponent(name[1]);
    },
    
    /**
     * load XML data and transform it into HTML
     */
    transform:function(src){
     var output = "";

     $.ajax({
      url: src,
      dataType: "xml",
      async: false,
      success: function(xml){
        output = ItemDetailTestWidget_detail_controller.transformXml(xml); 
      }
     });
     
     return output;
    },

    /**
     * Transform data into HTML
     */ 
    transformXml:function(xml){
        
        var output = "";
        var items = "";
        
        /**
         * For each element that matches itemName, create a new ItemTemplate and
         * replace placeholders in the template with values from the XML using the ItemElements 
         * and ItemAttrobutes lists
         */
        $(xml).find("status").each(
           function(){
             var item = "<!--  Licensed to the Apache Software Foundation (ASF) under one or more  contributor license agreements.  See the NOTICE file distributed with  this work for additional information regarding copyright ownership.  The ASF licenses this file to You under the Apache License, Version 2.0  (the 'License'); you may not use this file except in compliance with  the License.  You may obtain a copy of the License at      http://www.apache.org/licenses/LICENSE-2.0  Unless required by applicable law or agreed to in writing, software  distributed under the License is distributed on an 'AS IS' BASIS,  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the specific language governing permissions and  limitations under the License.--><div class='tweet'><div class='overview'>  <div class='quote'>${TEXT}</div></div><div class='meta-data'>  <div class='clear'>${NAME} (${SCREEN_NAME}) from ${LOCATION} at ${CREATED_AT} (using ${SOURCE} )    </div>    </div>    <div class='user clear'>      <h3>About ${NAME}</h3>      <div class='thumbnail'><img alt='Avatar for tweet author' src='${PROFILE_IMAGE_URL}'></div>      <p>${NAME} uses the screen name ${SCREEN_NAME}, and is based in ${LOCATION}</p>      <p>They describe themselves as '${DESCRIPTION}'          They provide more information about themselves at <a class='ui-link'>${URL}</a></p>      <p>They have ${FOLLOWERS_COUNT} followers, are listed in ${LISTED_COUNT} lists and follow ${FRIENDS_COUNT} people. They have tweeted ${STATUSES_COUNT} times.</p></div></div>";
             var elements = "name,screen_name,location,description,url,followers_count,listed_count,friends_count,statuses_count,text,profile_image_url,created_at,source".split(",");
             for (var i=0;i<elements.length;i++){
                var element = elements[i]; 
                var pattern = "\\$\{" + element.toUpperCase() +"\}";
                item = item.replace(new RegExp(pattern,'g'), $(this).find(element).first().text());
             }
             var attributes = "id".split(",");
             for (var i=0;i<attributes.length;i++){
                var attribute = attributes[i]; 
                var pattern = '\\$\{'+attribute.toUpperCase()+'\}';
                item = item.replace(new RegExp(pattern,'g'), $(this).attr(attribute));
             }
             items += item;
           }
        );
        
        output = "<div>${ITEMS}</div>".replace("${ITEMS}", items);
        return output;
    }


}

/**
 * Initialise page
 */
$('#home').live('pageshow',function(event) {
   ItemDetailTestWidget_detail_controller.init(); 
});



$('#tile').live('pageinit',function(event) { 
    $('#tile').click(function() {
        window.widget.views.openUrl("http://www.apache.org/widgets/CHANGEME-itemDetail", null, "_blank");
    });
});

