

/**
 * The ScanningBaseTestWidget_controller object
 * This is used to wire up the view and model with actions
 */ 
var ScanningBaseTestWidget_controller = {
    /**
     * A dictionary of callback functions that are called whenever an
     * event is fired by this widget.
     */
    callbacks: {},

    init:function() {
        ScanningBaseTestWidget_controller.update();
    },

    /**
     * Update the display
     */
    update:function() { 
        // Is the viewport large enough for the full view?
        var viewport = ScanningBaseTestWidget_controller.getViewport();
        if (viewport.height <= 310  || viewport.width <= 310) {
            $.mobile.changePage($('#tile'));
        } else {
            $.mobile.changePage($('#home'));
        }
    },

   /**
    * Get the current title for this widget.
    */
    getTitle:function() {
        return "Test Widget from Scanning Template";
    },

    /**
     * Get the viewport width and height.
     * returns an object with width and height properties.
     */
    getViewport:function() {
	var e = window
	, a = 'inner';
	if ( !( 'innerWidth' in window ) ) {
	    a = 'client';
	    e = document.documentElement || document.body;
	}
	return { width : e[ a + 'Width' ] , height : e[ a + 'Height' ] }
    },

    /**
     * Register a callback function. 
     *
     * type: the name of the type of event to respond to 
     *
     * widget: [optional] the name of the widget where the event must
     * occur for the callback to be executed. This allows callbacks to
     * be register so that they will only respond to events in
     * specific widgets, or to all events.
     */
    register:function(event, callback, widget) {
	if (widget === undefined) {
	    var cbks = ScanningBaseTestWidget_controller.callbacks[event];
	} else {
	    var cbks = ScanningBaseTestWidget_controller.callbacks[widget + "." + event];
	}
	if (cbks === undefined) {
	    cbks = new Array();
	}
	cbks.push(callback);
	ScanningBaseTestWidget_controller.callbacks[event] = cbks;
    },

    /**
     * Execute all the callbacks registered for a given event.
     *
     * The event object is passed directly to the callback function
     * and can contani any number of properties. Two properties that
     * important to the callback functionality are:
     *
     * type: the name of the type of event to respond to 
     *
     * widget: [optional] the name of the widget where the event
     * occured. This allows callbacks to be register so that they will
     * only respond to events in specific widgets, or to all events.
     */
    executeCallbacks:function(event) {
	// Execute all callbacks not restricted to a widget
	var cbks = ScanningBaseTestWidget_controller.callbacks[event.type];
	if (cbks === undefined) return;
	for (var i = 0; i < cbks.length; i++) {
	    cbks[i](event);
	}

	// Execute all callbacks restricted to a widget
	if (event.widget === undefined) return;
	var cbks = ScanningBaseTestWidget_controller.callbacks[event.widget + "." + event.type];
	if (cbks === undefined) return;
	for (var i = 0; i < cbks.length; i++) {
	    cbks[i](event);
	}
    }
};

$('#home').live('pageinit',function(event) {
   ScanningBaseTestWidget_controller.init(); 
});

$('body').bind('orientationchange',function(event){
    ScanningBaseTestWidget_controller.update();
})



/**
 * The @widget.shortname@_scanning_controller object This is used to
 * allow users using a switch device to interact efficiently with a
 * widget.
 */ 
var ScanningBaseTestWidget_scanning_controller = {
    scanning: true, // indicates if we are currently scanning
    delay: 1000, // time in milliseconds between focus change
    interval: null, // The interval object controlling the scan
    scanElements: null, // The elements to scan over
    currentElementIdx: 0, // The index of the currently scanning element

    init:function() {
        ScanningBaseTestWidget_scanning_controller.scanElements = $('[data-scanOrder]');
        if (ScanningBaseTestWidget_scanning_controller.scanning) {
	    ScanningBaseTestWidget_scanning_controller.startScanning();
        };
    },

    /**
     * Action to take when switch is released.
     * The event contains details supplied by the switch.
     */
    switchUp:function(event) {
	if (event.keyCode === 32) {
	    ScanningBaseTestWidget_scanning_controller.scanElements[ScanningBaseTestWidget_scanning_controller.currentElementIdx].click();
	}
    },

    nextElement:function() {
	var idx = ScanningBaseTestWidget_scanning_controller.currentElementIdx;
	var elements = ScanningBaseTestWidget_scanning_controller.scanElements;

	var oldElement = $(elements[idx]);
	oldElement.fadeIn('slow', function() {
	    // Animation complete.
	});

	idx += 1;
	if (idx >= elements.length) {
	    idx = 0
	};

	var newElement = $(elements[idx]);
	newElement.fadeOut('slow', function() {
	    // Animation complete.
	});
	newElement.fadeIn('slow', function() {
	    // Animation complete.
	});
	ScanningBaseTestWidget_scanning_controller.currentElementIdx = idx;
    },

    startScanning:function() {
	ScanningBaseTestWidget_scanning_controller.scanning = true;
	ScanningBaseTestWidget_scanning_controller.interval = 
	    window.setInterval(ScanningBaseTestWidget_scanning_controller.nextElement, 
			       ScanningBaseTestWidget_scanning_controller.delay);
	$(document).keyup(ScanningBaseTestWidget_scanning_controller.switchUp);
    },

    stopScanning:function() {
	ScanningBaseTestWidget_scanning_controller.scanning = false;
	window.clearInterval(ScanningBaseTestWidget_scanning_controller.interval);
    }

};

$('#home').live('pageshow',function(event) {
    ScanningBaseTestWidget_scanning_controller.init(); 
});


$('#tile').live('pageinit',function(event) { 
    $('#tile').click(function() {
        window.widget.views.openUrl("http://www.apache.org/widgets/CHANGEME-scanning", null, "_blank");
    });
});



/**
 * The @widget.shortname@_scanning_controller object This is used to
 * allow users using a switch device to interact efficiently with a
 * widget.
 */ 
var ScanningBaseTestWidget_scanningBaseTest_controller = {
    init:function() {
	$('#button1').click(function() {
	    alert("Button 1 clicked");
	});
	$('#button2').click(function() {
	    alert("Button 2 clicked");
	});
	$('#button3').click(function() {
	    alert("Button 3 clicked");
	});
	$('#button4').click(function() {
	    alert("Button 4 clicked");
	});
	$('#button5').click(function() {
	    alert("Button 5 clicked");
	});
	$('#button6').click(function() {
	    alert("Button 6 clicked");
	});

	ScanningBaseTestWidget_scanning_controller.scanElements = $('[data-scanOrder]');
    },
};

$('#home').live('pageshow',function(event) {
    ScanningBaseTestWidget_scanningBaseTest_controller.init(); 
});

